@@ -2,7 +2,8 @@
 # the full copyright notices and license terms.
 
 try:
-    from trytond.modules.project_invoice_operation.tests.test_project_invoice_operation import suite
+    from trytond.modules.project_invoice_operation.tests.test_project_invoice_operation import (
+        suite)
 except ImportError:
     from .test_project_invoice_operation import suite
 
